#! /bin/sh
#  ------------------------------------------------------------
#  Company: Software- und Organisations-Service GmbH
#  Purpose: Startscript for JobScheduler Agent
#  ------------------------------------------------------------

### BEGIN INIT INFO
# Provides:          JobSchedulerAgent
# Required-Start:    $syslog $remote_fs
# Required-Stop:     $syslog $remote_fs
# Default-Start:     3 5
# Default-Stop:      0 1 2 6
# Description:       Start JobScheduler Agent
### END INIT INFO


### SETTINGS #############################################

# This variable has to point to the installation path of 
# the JobScheduler Agent. If this variable not defined 
# then the parent directory of this startscript is used.
### NOTE: 
# This variable is mandatory if this script is used for a  
# JobScheduler Agent service in /etc/init.d to find the 
# installation of the JobScheduler Agent.
#
# SCHEDULER_HOME=

# Set the user for the JobScheduler Agent. Otherwise the 
# current logged user is used. This variable has to be set 
# if this script is used for autostart to avoid that the 
# JobScheduler Agent is started with the 'root' user.
#
# SCHEDULER_USER=

# The default port of the JobScheduler Agent
#
SCHEDULER_AGENT_DEFAULT_HTTP_PORT=4445

# The http port of the JobScheduler Agent can be set here,
# as command line option -http-port (see usage) or as
# environment variable. Otherwise the above default port 
# is used.
# If only a port is specified then the JobScheduler Agent 
# listens to all available network interfaces.
# It is the same like 0.0.0.0:port.
# Use the form [ip address or hostname]:port for indicating 
# which network interfaces the JobScheduler Agent should 
# listen to.
# The command line option -http-port beats the environment 
# variable SCHEDULER_HTTP_PORT and the environment variable 
# SCHEDULER_HTTP_PORT beats the default port from 
# SCHEDULER_AGENT_DEFAULT_HTTP_PORT.
### NOTE:
# If you start the JobScheduler Agent with the command line 
# option -http-port then you must enter -http-port for 
# stop, status, restart too (see usage). It's recommended 
# to set this environment variable instead.
#
# SCHEDULER_HTTP_PORT=

# In addition to the http port a https port of the 
# JobScheduler Agent can be set here, as command line option 
# -https-port (see usage) or as environment variable.
# If only a port is specified then the JobScheduler Agent 
# listens to all available network interfaces.
# It is the same like 0.0.0.0:port.
# Use the form [ip address or hostname]:port for indicating 
# which network interfaces the JobScheduler Agent should 
# listen to.
# The command line option -https-port beats the environment 
# variable SCHEDULER_HTTPS_PORT.
#
# SCHEDULER_HTTPS_PORT=

# Set the directory where the JobScheduler Agent has the
# configuration, logs, etc. 
# The default is SCHEDULER_HOME
#
# SCHEDULER_DATA=

# Set the directory where the JobScheduler Agent log file 
# is created. The default is SCHEDULER_DATA/logs
#
# SCHEDULER_LOG_DIR=

# Set the directory where the JobScheduler Agent pid file 
# is created. The default is SCHEDULER_LOG_DIR
#
# SCHEDULER_PID_FILE_DIR=

# The working directory of the JobScheduler Agent is 
# SCHEDULER_HOME. Here you can set a different working 
# directory (e.g. $HOME). 
#
# SCHEDULER_WORK_DIR=

# Set the location of a script which is called by the 
# JobScheduler Agent to kill a process and it's children.
#
# SCHEDULER_KILL_SCRIPT=

# Actually JAVA_HOME is already set. If you want to use 
# another Java environment then you can set it here. If  
# no JAVA_HOME is set then the Java from the path is used
# (see 'which java').
#
# JAVA_HOME=

# With Java 1.8 the initial memory allocation has changed, 
# for details see https://kb.sos-berlin.com/x/aIC9
# As a result on start-up of the JobScheduler Agent an 
# excessive amount of virtual memory is assigned by Java.  
# The environment variables JAVA_OPTIONS and
# SCHEDULER_JOB_JAVA_OPTIONS can be used to apply memory 
# settings such as '-Xms100m' (default for JAVA_OPTIONS) 
# where the JobScheduler Agent uses the JAVA_OPTIONS and 
# each jobwhich is started by the Agent uses 
# SCHEDULER_JOB_JAVA_OPTIONS.
#
# JAVA_OPTIONS=
# SCHEDULER_JOB_JAVA_OPTIONS=

##########################################################


usage() 
{
  echo "Usage: `basename $0` command [options] [web services]"
  echo "  command:"
  echo "    start         [options]"
  echo "    start_docker  [options]"
  echo "    stop          [options]"
  echo "    abort         [options]"
  echo "    restart       [options]"
  echo "    status        [options] [web services]"
  echo "    kill          [options]"
  echo "  options:"
  echo "    -http-port=<[hostname or ip address:]number>   | default: $SCHEDULER_HTTP_PORT"
  echo "    -https-port=<[hostname or ip address:]number>  | default: $SCHEDULER_HTTPS_PORT"
  echo "    -data-directory=<location of data directory>   | default: $SCHEDULER_DATA"
  echo "    -timeout=<number>                              | in seconds; only for stop and restart"
  #echo "    -ip-address=<hostname or ip address>           | to listen to a specific host name or ip address"
  echo "    -kill-script=<location of kill script>         | only for start"
  echo "    -java-options=<java options>                   | default: ${JAVA_OPTIONS}; see also https://kb.sos-berlin.com/x/aIC9"
  echo "    -job-java-options=<java options>               | see also https://kb.sos-berlin.com/x/aIC9"
  echo "  web services:"
  echo "    overview                                       | default"
  echo "    task                                           | running JobScheduler Agent tasks"
  echo "    tunnel                                         | tunnels summary"
  echo "    tunnel/                                        | list of tunnels"
  echo "    command                                        | running command summary"
  echo "    command/                                       | list of running commands (watching file_order_source)"
  more_info
}

more_info()
{
  echo "see also https://kb.sos-berlin.com/x/kQiX for more information."
}

start_agent() 
{
  SCHEDULER_EXIT=0
  if running
  then
    echo "...JobScheduler Agent(${SCHEDULER_PORT}) is already running with pid=`get_pid`!"
    exit 0
  fi
  remove_crash_file
  SCHEDULER_CLASSPATH="${SCHEDULER_HOME}/lib/log/${SCHEDULER_LOG_BRIDGE}/*:${SCHEDULER_HOME}/lib/jdbc/*:${SCHEDULER_HOME}/lib/3rd-party/*:${SCHEDULER_HOME}/lib/sos/*:${SCHEDULER_HOME}/lib/"
  CUR_DIR="`pwd`"
  cd "${SCHEDULER_WORK_DIR}"
  export_env_for_watchdog
  "${SCHEDULER_HOME}/bin/jobscheduler_agent_watchdog.sh" -${SCHEDULER_PORT} &
  SCHEDULER_EXIT=$?
  cd "${CUR_DIR}" 
}

start_agent_in_docker()
{
  SCHEDULER_EXIT=0
  if running
  then
     echo "...JobScheduler Agent(${SCHEDULER_PORT}) is already running with pid=`get_pid`!"
     exit 0
  fi
  remove_crash_file 
  SCHEDULER_CLASSPATH="${SCHEDULER_HOME}/lib/log/${SCHEDULER_LOG_BRIDGE}/*:${SCHEDULER_HOME}/lib/jdbc/*:${SCHEDULER_HOME}/lib/3rd-party/*:${SCHEDULER_HOME}/lib/sos/*:${SCHEDULER_HOME}/lib/stdout/"
  CUR_DIR="`pwd`"
  cd "${SCHEDULER_WORK_DIR}"
  "${JAVABIN}" ${JAVA_OPTIONS} -classpath "${SCHEDULER_CLASSPATH}" com.sos.scheduler.engine.agent.main.AgentMain -http-port=${SCHEDULER_HTTP_PORT} ${HTTPS_PORT_OPTION} -log-directory="${SCHEDULER_LOG_DIR}" ${KILL_SCRIPT_OPTION} &
  SCHEDULER_EXIT=$?
  cd "${CUR_DIR}"
  trap "stop_agent stop_docker" SIGHUP SIGINT SIGTERM
  if [ "${SCHEDULER_EXIT}" = "0" ]
  then
    create_pid_file $!
    SCHEDULER_PID=$!
    echo "...JobScheduler Agent(${SCHEDULER_PORT}) is started with pid=${SCHEDULER_PID}!"
    wait "${SCHEDULER_PID}"
	SCHEDULER_EXIT=$?
	if [ "${SCHEDULER_EXIT}" != "0" ]
	then 
	  date "+%Y-%m-%d %T,%3N %z [info]  JobScheduler Agent terminated abnormal" >> "${SCHEDULER_LOGFILE}.log"
	  call_crash_file
	fi
  fi
}

stop_agent() 
{
  if running
  then
    if [ "$1" = "stop_docker" ]
    then
      SCHEDULER_LOGFILE=
    fi
    echo "...try to terminate the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}."
    if [ -z "${SCHEDULER_TIMEOUT}" ]
    then
      command_with_agent_client "{\$TYPE: Terminate, sigtermProcesses: false}"
    else
      command_with_agent_client "{\$TYPE: Terminate, sigtermProcesses: false, sigkillProcessesAfter: ${SCHEDULER_TIMEOUT}}"
    fi
  else
    echo "...not started!"
    return 0 
  fi
  if [ "${SCHEDULER_EXIT}" != "0" ]
  then
    echo "...could not terminate the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}!"
    exit 3
  else
    LOOP_COUNTER=2
    sleep 2
    while running
    do
      test "${LOOP_COUNTER}" = "2" && printf "...waiting for termination"
      printf ".."
      #printf "..%d" "${LOOP_COUNTER}"
      LOOP_COUNTER=`expr ${LOOP_COUNTER} + 2`
      sleep 2
    done
    echo "...terminated!"
    remove_pid_file
    return 0
  fi
  return 0
}

abort_agent() 
{
  if running
  then
    echo "...try to abort the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}."
    command_with_agent_client "{\$TYPE: AbortImmediately}"
  else
    echo "...not started!"
    return 0 
  fi
  sleep 2
  if running
  then
    echo "...could not abort the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}!"
    exit ${SCHEDULER_EXIT}
  else
    SCHEDULER_EXIT=0
    echo "...aborted!"
    remove_pid_file
    return 0
  fi
  return 0
}

status_agent() 
{  
  SCHEDULER_URLS=
  for param in "$@"
  do
    if ! is_option "$param"
    then
      if ! is_json "$param"
      then
        param=`echo "/$param" | sed 's;^//;/;'`
        SCHEDULER_URLS="$SCHEDULER_URLS $param"
      fi
    fi
  done
  if [ -z "$SCHEDULER_URLS" ]
  then
    mycommand /overview
  else
    mycommand $SCHEDULER_URLS
  fi
  #exit 3 if program is not running according LSB 3.1
  if [ "${SCHEDULER_EXIT}" != "0" ]
  then
    echo "...JobScheduler Agent(${SCHEDULER_PORT}) not started?"
    SCHEDULER_EXIT=3
  fi
}

kill_agent() 
{
  if running
  then
    SCHEDULER_PID=`get_pid`
    echo "...try to kill (SIGTERM) the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}."
    kill -15 ${SCHEDULER_PID} 2> /dev/null
    sleep 5
    if ps -p ${SCHEDULER_PID} > /dev/null 2>&1
    then
      echo "...try once more with SIGKILL."
      kill -9 ${SCHEDULER_PID}
      kill_err=$?
      if [ $kill_err -eq 0 ]
      then
        echo "...killed!"
        remove_pid_file
        return 0
      else
        echo "...could not kill the JobScheduler Agent(${SCHEDULER_PORT}) with pid=${SCHEDULER_PID}!"
        exit 3
      fi
    else
      echo "...killed!"
      remove_pid_file
      return 0 
    fi
  else
    echo "...not started!" 
  fi
  return 0 
}

mycommand()
{
  if with_curl "$@"
  then
    command_with_curl "$@"
  else
    command_with_agent_client "$@"
  fi
}

command_with_agent_client()
{
  SCHEDULER_EXIT=0
  SCHEDULER_CLASSPATH="${SCHEDULER_HOME}/lib/log/${SCHEDULER_LOG_BRIDGE}/*:${SCHEDULER_HOME}/lib/3rd-party/*:${SCHEDULER_HOME}/lib/sos/*:${SCHEDULER_HOME}/lib/"
  "${JAVABIN}" -DLOGFILE="${SCHEDULER_LOGFILE}" ${JAVA_OPTIONS} -classpath "${SCHEDULER_CLASSPATH}" com.sos.scheduler.engine.agent.client.main.AgentClientMain "`get_url`" "$@"
  SCHEDULER_EXIT=$?
}

command_with_curl()
{
  for param in $@
  do
  	curl "`get_url`/jobscheduler/agent/api${param}" 
  	SCHEDULER_EXIT=$?
  	if [ "$SCHEDULER_EXIT" != "0" ]
  	then
  	  echo "error with webservice `get_url`/jobscheduler/agent/api${param}" 
  	  return 1
  	else
  	  echo "---"
  	fi
	done
	return 0
}

get_pid() 
{
  if [ -r "${SCHEDULER_PID_FILE}" ]
  then
    cat "${SCHEDULER_PID_FILE}"
    return 0
  else
    SCHEDULER_PID=`get_pid_from_ps`
    echo "${SCHEDULER_PID}"
    if [ "${SCHEDULER_PID}" = "" ]
    then
      return 1
    fi
  fi 
  return 0 
}

get_pid_from_ps() 
{ 
  ps -ef -w -w | egrep "com\.sos\.scheduler\.engine\.agent\.main\.AgentMain.*-http-port=${SCHEDULER_HTTP_PORT}" | grep -v "egrep" | awk '{print $2}'
}

running()
{
  SCHEDULER_PID=`get_pid 2>/dev/null` || return 1 
  if kill -0 ${SCHEDULER_PID} 2>/dev/null
  then
    return 0
  else
    remove_pid_file
  fi
  return 1
}

with_curl()
{
  which curl >/dev/null 2>/dev/null || return 1
  return 0
}

is_json()
{
  echo "$@" | grep "{" >/dev/null 2>/dev/null && return 0
  return 1
}

is_option()
{
  first_letter=`echo "$1" | head -q -c 1`
  if [ "$first_letter" = "-" ]
  then
    return 0
  fi
  return 1
}

create_pid_file() 
{
	SCHEDULER_PID=$1
	echo "${SCHEDULER_PID}" > "${SCHEDULER_PID_FILE}"
	if [ ! -f "${SCHEDULER_PID_FILE}" ]
	then
	  echo "...pid file \"${SCHEDULER_PID_FILE}\" could not be created!"
    echo "...please check the permissions in \"${SCHEDULER_PID_FILE_DIR}\"."
    more_info
    #kill -9 ${SCHEDULER_PID}
    exit 3
  else
    chmod 666 "${SCHEDULER_PID_FILE}" 2>/dev/null
	fi 
}

remove_pid_file()
{
  rm -f "${SCHEDULER_PID_FILE}" 2>/dev/null
}

remove_crash_file()
{
  rm -f "${SCHEDULER_CRASH_FILE}" 2>/dev/null 
}

mkdir_error()
{
  if [ "$1" != "0" ]
  then 
    echo "...could not create \"$2\""
    echo "please create \"$2\" manually with read and write permissions for the user \"${SCHEDULER_USER}\""
    MKDIR_ERROR_EXISTS=1
    more_info
  fi
}

call_crash_file()
{
  if [ ! -s "${SCHEDULER_CRASH_FILE}" ]
  then
    date "+%Y-%m-%d %T,%3N %z [info]  \"${SCHEDULER_CRASH_FILE}\" doesn't exist" >> "${SCHEDULER_LOGFILE}.log"
  else
    /bin/sh "${SCHEDULER_CRASH_FILE}"
  fi
}

export_env_for_watchdog()
{
  export SCHEDULER_HOME
  export SCHEDULER_DATA
  export SCHEDULER_PORT
  export SCHEDULER_HTTP_PORT
  export HTTPS_PORT_OPTION
  export SCHEDULER_LOGFILE
  export JAVABIN
  export SCHEDULER_LOG_DIR
  export KILL_SCRIPT_OPTION
  export SCHEDULER_CRASH_FILE
  export JAVA_OPTIONS
  export SCHEDULER_JOB_JAVA_OPTIONS
  export SCHEDULER_CLASSPATH
  export SCHEDULER_PID_FILE
  export SCHEDULER_PID_FILE_DIR
}

get_port()
{
  echo "$1" | cut -d : -f 2 
}

get_url()
{
  echo "http://`add_ip_address ${SCHEDULER_HTTP_PORT} 127.0.0.1`"   
}

add_ip_address()
{
  IP_ADDRESS=`echo "$1" | grep ":" | cut -d : -f 1`
  NEW_IP_ADDRESS="$2"
  if [ ! -z "$NEW_IP_ADDRESS" ]
  then
    NEW_IP_ADDRESS="${NEW_IP_ADDRESS}:"
  fi
  if [ -z "${IP_ADDRESS}" ] || [ "${IP_ADDRESS}" = "0.0.0.0" ]
  then
    echo "${NEW_IP_ADDRESS}$1"
  else
    echo "$1"
  fi    
}

create_folder()
{
  if [ ! -d "$1" ]
  then
    if [ "${CURRENT_USER}" = "${SCHEDULER_USER}" ]
    then
	  mkdir -p "$1" 2>/dev/null
    else
	  su - ${SCHEDULER_USER} -c "mkdir -p \"$1\" 2>/dev/null"
    fi
  fi
  mkdir_error $? "$1"
}


##########################
# set logging impl (log4j or logback)
SCHEDULER_LOG_BRIDGE=log4j


##########################
# set and check home
SCHEDULER_BINDIR="`dirname $0`"
SCHEDULER_BINDIR="`cd \"${SCHEDULER_BINDIR}\" >/dev/null && pwd`"
SCHEDULER_STARTSCRIPT="${SCHEDULER_BINDIR}/`basename $0`"
if [ -z "${SCHEDULER_HOME}" ]
then
  SCHEDULER_HOME="`cd \"${SCHEDULER_BINDIR}/..\" >/dev/null && pwd`"
fi

SCHEDULER_LIBDIR=${SCHEDULER_HOME}/lib
if [ ! -d "${SCHEDULER_LIBDIR}" ]
then
  echo "...the directory "${SCHEDULER_LIBDIR}" is missing!"
  echo "did you move the startscript?"
  echo "please set the SCHEDULER_HOME variable in '$0'."
  more_info
  exit 3
fi


##########################
# set user
CURRENT_USER=`whoami 2>/dev/null` 
whoami_err=$?
# 'whoami' on Solaris sometimes not available
if [ ${whoami_err} -ne 0 ]
then
  CURRENT_USER=`id | sed 's/.*uid=[^(]*(\([^)]*\)).*/\1/'`
fi
if [ -z "${SCHEDULER_USER}" ]
then
  SCHEDULER_USER=${CURRENT_USER}
  #if [ "${CURRENT_USER}" = "root" ]
  #then
  #  echo "The current SCHEDULER_USER is 'root'!"
  #  echo "Please set the SCHEDULER_USER variable in '$0'."
  #  echo "If you really want the 'root' user then set"
  #  echo "SCHEDULER_USER=root in '$0'."
  #  more_info
  #  exit 2
  #fi
fi


##########################
# set http port etc.
SCHEDULER_TIMEOUT=
KILL_SCRIPT_OPTION=
HTTPS_PORT_OPTION=
SCHEDULER_PORT=
for param in "$@"
do
  case "$param" in
  	 -http-port=*)        SCHEDULER_HTTP_PORT=`echo "$param" | sed 's/-http-port=//'`
  	                      ;;
  	 -https-port=*)       SCHEDULER_HTTPS_PORT=`echo "$param" | sed 's/-https-port=//'`
                          ;;
  	 -data-directory=*)   SCHEDULER_DATA=`echo "$param" | sed 's/-data-directory=//'`
                          ;;
  	 -timeout=[0-9]*)     SCHEDULER_TIMEOUT=`echo "$param" | sed 's/-timeout=//'`
  	                      ;;
  	 -kill-script=*)      SCHEDULER_KILL_SCRIPT=`echo "$param" | sed 's/-kill-script=//'`
  	                      ;;
  	 -job-java-options=*) SCHEDULER_JOB_JAVA_OPTIONS=`echo "$param" | sed 's/-job-java-options=//'`
  	                      ;;
  	 -java-options=*)     JAVA_OPTIONS=`echo "$param" | sed 's/-java-options=//'`
  	                      ;;
     
  esac
done

test -z "${SCHEDULER_HTTP_PORT}" && SCHEDULER_HTTP_PORT=`add_ip_address "${SCHEDULER_AGENT_DEFAULT_HTTP_PORT}" "${SCHEDULER_IP_ADDRESS}"`
SCHEDULER_PORT=`get_port "${SCHEDULER_HTTP_PORT}"`
test -z "${SCHEDULER_KILL_SCRIPT}" || KILL_SCRIPT_OPTION="-kill-script=\"${SCHEDULER_KILL_SCRIPT}\""
test -z "${SCHEDULER_HTTPS_PORT}" || HTTPS_PORT_OPTION="-https-port=${SCHEDULER_HTTPS_PORT}"



##########################
# set pid file
test -z "${SCHEDULER_DATA}" && SCHEDULER_DATA="${SCHEDULER_HOME}/var_${SCHEDULER_PORT}"
test -z "${SCHEDULER_LOG_DIR}" && SCHEDULER_LOG_DIR="${SCHEDULER_DATA}/logs"
test -z "${SCHEDULER_PID_FILE_DIR}" && SCHEDULER_PID_FILE_DIR="${SCHEDULER_LOG_DIR}"
SCHEDULER_PID_FILE="${SCHEDULER_PID_FILE_DIR}/jobscheduler_agent_${SCHEDULER_PORT}.pid"
MKDIR_ERROR_EXISTS=0 
create_folder "${SCHEDULER_DATA}"
create_folder "${SCHEDULER_LOG_DIR}"
if [ "${SCHEDULER_LOG_DIR}" != "${SCHEDULER_PID_FILE_DIR}" ]
then 
  create_folder "${SCHEDULER_PID_FILE_DIR}"
fi
create_folder "${SCHEDULER_DATA}/tmp"
create_folder "${SCHEDULER_DATA}/config/private"
if [ "${MKDIR_ERROR_EXISTS}" = 1 ]
then
  exit 4
fi


##########################
# set log file basename
SCHEDULER_LOGFILE="${SCHEDULER_LOG_DIR}/jobscheduler_agent_${SCHEDULER_PORT}"


##########################
# set kill script location etc.
test -z "${KILL_TASK_LOG_FILE}" &&  KILL_TASK_LOG_FILE=${SCHEDULER_LOG_DIR}/agent_kill_task_${SCHEDULER_PORT}.log
SCHEDULER_CRASH_FILE="${SCHEDULER_DATA}/tmp/kill_tasks_after_crash.sh"
export KILL_TASK_LOG_FILE


##########################
# set working directory
test -z "${SCHEDULER_WORK_DIR}" && SCHEDULER_WORK_DIR="${SCHEDULER_HOME}"


##########################
# set java options
test -z "${JAVA_OPTIONS}" && JAVA_OPTIONS="-Xms100m"
if [ -z "${SCHEDULER_JOB_JAVA_OPTIONS}" ]
then
  SCHEDULER_JOB_JAVA_OPTIONS="-DLOGFILE=${SCHEDULER_LOGFILE}"
else
  SCHEDULER_JOB_JAVA_OPTIONS="-DLOGFILE=${SCHEDULER_LOGFILE} ${SCHEDULER_JOB_JAVA_OPTIONS}"
fi


##########################
# set and check java
JAVABIN=`which java 2>/dev/null`
test ! -z "$JAVA_HOME" && test -x "$JAVA_HOME/bin/java" && JAVABIN="$JAVA_HOME/bin/java"
if [ -z "$JAVABIN" ]
then
  echo "...Java environment could not determined"
  echo "...please set JAVA_HOME properly"
  more_info 
  exit 5
fi
JAVA_VERSION=`"${JAVABIN}" -version 2>&1 | awk 'NR==1 {print $3}' | sed 's/[^0-9]/ /g' | awk '{print ($1*10000)+$2}'`
if [ ! -z "$JAVA_VERSION" ] && [ "$JAVA_VERSION" -gt 0 ] && [ "$JAVA_VERSION" -lt 10008 ]
then
  echo "...the Java version of \"${JAVABIN}\" is less than 1.8.x"
  echo "...please install a Java runtime environment at least 1.8.x"
  more_info 
  exit 5
fi


##########################
# ... and action
case "$1" in
    start)
    		if [ "${CURRENT_USER}" = "${SCHEDULER_USER}" ]
    		then
    		  start_agent
    		else
    		  su - ${SCHEDULER_USER} -c "\"${SCHEDULER_STARTSCRIPT}\" $*"
    		fi
        ;;
    start_docker)
    		start_agent_in_docker
        ;;
    stop)
        stop_agent
        ;;
    restart)
        if [ "${CURRENT_USER}" = "${SCHEDULER_USER}" ]
    		then
    		  stop_agent
          start_agent
    		else
    		  su - ${SCHEDULER_USER} -c "\"${SCHEDULER_STARTSCRIPT}\" $*"
    		fi
        ;;
    abort)
        abort_agent
        ;;
    kill)
        kill_agent
        ;;
    status)
        shift
        status_agent "$@"
        ;;
    setup)
        echo "Directory for logs and pid files exists!"
        echo "Java version ok!"
        ;;
    *)
        usage
        ;;
esac

test -z "${SCHEDULER_EXIT}" && SCHEDULER_EXIT=0
exit $SCHEDULER_EXIT